<?php

$txt['config_name'] = 'francais';

$txt['charset'] = 'ISO-8859-1';



$txt['Yes'] = 'Oui';

$txt['No'] = 'Non';

$txt['language'] = 'Langue';

$txt['close'] = 'Fermer';

$txt['add_field'] = 'Ajouter un champ';

$txt['change_type'] = 'Changer le type';

$txt['select'] = 'S&eacute;lectionner';

$txt['options'] = 'Options';

$txt['setup'] = 'Configuration';

$txt['install'] = 'Installation';

$txt['create_db'] = 'Cr&eacute;er une base';

$txt['manual_request'] = 'Requ&ecirc;te manuelle';

$txt['create_tbl'] = 'Cr&eacute;er une nouvelle table';

$txt['delete_db'] = 'Supprimer cette base';

$txt['display_content'] = 'Afficher le contenu';

$txt['add_record'] = 'Ajouter un enregistrement';

$txt['add_comment'] = 'Modifier le commentaire';

$txt['dump_tbl'] = 'Exporter la table';

$txt['rename_tbl'] = 'Renommer la table';

$txt['copy_tbl'] = 'Copier la table';

$txt['move_tbl'] = 'D&eacute;placer la table';

$txt['order_tbl'] = 'Ordonner la table';

$txt['order_tbl_by'] = 'Ordonner la table par';

$txt['delete_tbl'] = 'Supprimer la table';

$txt['delete_tbls'] = 'Supprimer les tables';

$txt['check_tbl'] = 'V&eacute;rifier la table';

$txt['analyse_tbl'] = 'Analyser la table';

$txt['repare_tbl'] = 'R&eacute;parer la table';

$txt['optimize_tbl'] = 'Optimiser la table';

$txt['optimize_tbls'] = 'Optimiser les tables';

$txt['back_2_tbl'] = 'Retour  la table';

$txt['back_2_db'] = 'Retour  la base';

$txt['execute'] = 'Executer';

$txt['no_tbl'] = 'Aucune table dans cette base.';

$txt['tbl'] = 'Table';

$txt['db'] = 'Base';

$txt['records'] = 'Enregistrements';

$txt['size'] = 'Taille';

$txt['records2'] = 'Enregistrement(s)';

$txt['tbl_name'] = 'Nom de la table';

$txt['nb_fields'] = 'Nombre de champs';

$txt['create_the_tbl'] = 'Cr&eacute;er la table';

$txt['tbl_creation'] = 'Cr&eacute;ation de la table';

$txt['key'] = 'Cl&eacute;';

$txt['field_name'] = 'Nom du champ';

$txt['type'] = 'Type';

$txt['can_be_null'] = 'Null autoris&eacute;';

$txt['length'] = 'Longueur';

$txt['propose_opt'] = 'Proposer des optimisations structurelles sur la table';

$txt['cardinality'] = 'Cardinalit';

$txt['primary'] = 'Primaire';

$txt['index'] = 'Index';

$txt['unique'] = 'Unique';

$txt['fulltext'] = 'Texte entier';

$txt['attribs'] = 'Attributs';

$txt['default_value'] = 'Valeur par d&eacute;faut';

$txt['auto_incr'] = 'Incr&eacute;mentation automatique';

$txt['comments'] = 'Commentaires';

$txt['sql_query'] = 'Requ&ecirc;te SQL';

$txt['tbl_created'] = 'La table a &eacute;t&eacute; cr&eacute;&eacute;e avec succ&egrave;s.';

$txt['no_records'] = 'Aucun enregistrement.';

$txt['from'] = 'De';

$txt['to'] = '&agrave;';

$txt['modify'] = 'Modifier';

$txt['cancel'] = 'Annuler';

$txt['delete'] = 'Supprimer';

$txt['query_done'] = 'Requ&ecirc;te effectu&eacute;e';

$txt['confirm_query'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir effectuer la requ&ecirc;te';

$txt['query_is_about'] = 'La requ&ecirc;te concerne';

$txt['tbl2'] = 'table(s)';

$txt['and'] = 'et';

$txt['the_db'] = 'La base';

$txt['has_been_created'] = 'a &eacute;t&eacute; cr&eacute;&eacute;e';

$txt['db_name'] = 'Nom de la base';

$txt['create_the_db'] = 'Cr&eacute;er la base';

$txt['name'] = 'Nom';

$txt['xtra'] = 'Extra';

$txt['choice'] = 'S&eacute;lection';

$txt['delete_choice'] = 'Supprimer la s&eacute;lection';

$txt['modif_choice'] = 'Modifier la s&eacute;lection';

$txt['field'] = 'Champ';

$txt['fields'] = 'Champs';

$txt['never_done'] = 'Jamais effectu&eacute;e';

$txt['next_auto'] = 'Prochain "auto_increment"';

$txt['tbl_comment'] = 'Commentaire associ&eacute;  cette table';

$txt['type_records'] = 'Type Enregistrement';

$txt['record_size'] = 'Taille moyenne d\'un enregistrement';

$txt['data_size'] = 'Taille des donn&eacute;es';

$txt['index_size'] = 'Taille de l\'index';

$txt['creation_date'] = 'Date de cr&eacute;ation';

$txt['last_update_date'] = 'Date de derni&egrave;re mise &agrave; jour';

$txt['last_check_date'] = 'Date de derni&egrave;re v&eacute;rification';

$txt['lost_space'] = 'Attention espace perdu';

$txt['unit'] = 'octets';

$txt['comment_recorded'] = 'Commentaire enregistr&eacute;.';

$txt['a_comment'] = 'Commentaire';

$txt['record'] = 'Enregistrer';

$txt['function'] = 'Fonction';

$txt['value'] = 'Valeur';

$txt['add'] = 'Ajouter';

$txt['display_records'] = 'Affichage des enregistrements';

$txt['nb_records'] = 'Nombre d\'enregistrements total dans la table';

$txt['empty_tbl'] = 'La table est vide';

$txt['emptyer_tbl'] = 'Vider la table';

$txt['emptyer_tbls'] = 'Vider les tables';

$txt['tbl_renamed'] = 'La table s\'appelle d&eacute;sormais';

$txt['back'] = 'Retour';

$txt['old_name'] = 'Ancien nom';

$txt['new_name'] = 'Nouveau nom';

$txt['rename'] = 'Renommer';

$txt['invalid_dest'] = 'La table de destination n\'est pas valide !';

$txt['the_tbl'] = 'La table';

$txt['copy_successful'] = 'a &eacute;t&eacute; copi&eacute;e avec succ&egrave;s';

$txt['dest'] = 'Destination';

$txt['structure'] = 'Structure';

$txt['data_struc'] = 'Structure + donn&eacute;es';

$txt['copy_tbl'] = 'Copier la table';

$txt['move_successful'] = 'a &eacute;t&eacute; d&eacute;plac&eacute;e avec succ&egrave;s';

$txt['move'] = 'D&eacute;placer';

$txt['modif_done'] = 'Modifications effectu&eacute;es';

$txt['choose_field'] = 'Veuillez choisir au moins un champ';

$txt['confirm_delete'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer le(s) champ(s)';

$txt['after'] = 'Apr&egrave;s';

$txt['position'] = 'Position';

$txt['tbl_begin'] = 'D&eacute;but de table';

$txt['tbl_end'] = 'Fin de table';

$txt['the_key'] = 'La cl&eacute;';

$txt['been_deleted'] = 'a &eacute;t&eacute; supprim&eacute;e';

$txt['confirm_key'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer la cl&eacute;';

$txt['type_now'] = 'est d&eacute;sormais de type';

$txt['CtrlA'] = 'S&eacute;lectionner tout';

$txt['launch_query'] = 'Lancer la requ&ecirc;te';

$txt['incoming_sql'] = 'Importer';

$txt['no_incoming_sql'] = 'Aucun fichier d\'insertion trouv dans le repertoire <b>incoming/</b>';

$txt['no_incoming_dir'] = 'Pas de rpertoire <B>incoming/</B>';

$txt['display'] = 'Afficher';

$txt['displaying'] = 'Affichage de';

$txt['timed_query'] = 'Requ&ecirc;te effectu&eacute;e en';

$txt['secondes'] = 'secondes';

$txt['done_queries'] = 'requ&ecirc;te(s) effectu&eacute;es';

$txt['multiple_queries'] = 'Requ&ecirc;tes multiples';

$txt['close_popup'] = 'Fermer le popup';

$txt['close_window'] = 'Fermer cette fen&ecirc;tre';

$txt['next'] = 'Suivant';

$txt['host'] = 'Hte';

$txt['user'] = 'Utilisateur';

$txt['password'] = 'Mot de passe';

$txt['apply'] = 'Appliquer';

$txt['ok'] = 'ok';

$txt['default_value'] = 'Valeur par dfaut';

$txt['tips_day'] = 'Astuce du jour';

$txt['next_tip'] = 'Astuce suivante';

$txt['dont_show_again'] = 'Ne plus afficher';

$txt['upload_csv'] = 'Vous pouvez insrer un fichier CSV';

$txt['upload_sql'] = 'Vous pouvez insrer un fichier SQL';

$txt['on_this_page'] = 'sur cette page';

$txt['dump_this_query'] = 'Exporter avec cette requ&ecirc;te';

$txt['new_type'] = 'Nouveau type de la table';

$txt['sure_update'] = 'tes-vous sur(e) de vouloir mettre  jour tous les enregistrements';

$txt['order_by'] = 'Order by';

$txt['where'] = 'Clause WHERE';

$txt['criteria'] = 'Critre';

$txt['order'] = 'Ordre';

$txt['input_invalid'] = 'Votre saisie comporte des erreurs';

$txt['action_mult'] = 'Action sur les tables s&eacute;lectionn&eacute;es';

$txt['show_mysql_state'] = 'Afficher l\'tat du serveur MySQL';

$txt['show_mysql_vars'] = 'Afficher les variables du serveur MySQL';

$txt['show_mysql_process'] = 'Afficher les processus du serveur MySQL';

$txt['not_allowed'] = 'Vous n\'tes pas autoris  voir cette page';

$txt['show_full_text'] = 'Afficher les textes entiers';

$txt['hide_full_text'] = 'Cacher les textes';

$txt['error_occured'] = 'Une erreur a eu lieu';

$txt['empty'] = 'Vide';

$txt['fixed'] = 'Fixe';

$txt['dynamic'] = 'Dynamique';

$txt['compressed'] = 'Compress';

$txt['upload_not_allowed'] = 'L\'upload via formulaire est interdit par votre hbergeur. Vous ne pouvez donc pas uploader vos sauvegardes via HTTP';

$txt['desc_tbls'] = 'Structure des tables';

$txt['desc_in_progress'] = 'Affichage de la structure en cours';

$txt['null'] = 'Null';

$txt['horizontal_mode'] = 'Mode horizontal';

$txt['vertical_mode'] = 'Mode vertical';

$txt['filter'] = 'Filtrer';

$txt['filter_db'] = 'Filtrer les bases';

$txt['filter_tbl'] = 'Filtrer les tables';

$txt['overwrite'] = 'Ecraser la table de destination';

$txt['expl_enum'] = '<SUP>*</SUP> Si le champ est de type ENUM ou SET, entrez les valeurs comme ceci : \'valeur1\', \'valeur2\'... Si un \\ ou une apostrophe est ncessaire, rajoutez lui un \\ (ex : \\\\ pour \ et \\\' pour \')';

$txt['explain'] = 'Expliquer la requ&ecirc;te';

$txt['text'] = 'Texte';

$txt['crypt'] = 'Cryptage';

$txt['dates'] = 'Dates';

$txt['misc'] = 'Divers';

$txt['login_access'] = 'Identification pour l\'accs  eSKUeL';

$txt['login_title'] = 'Accs  eSKUeL';

$txt['login_loginname'] = 'Votre login';

$txt['login_password'] = 'Votre mot de passe';

$txt['login_failed'] = 'L\'identification a chou';



$txt['dump_structure_only'] = 'Structure seule';

$txt['dump_structure_data'] = 'Structure + donn&eacute;es';

$txt['dump_data_only'] = 'Donn&eacute;es seules';

$txt['dump_drop_table'] = 'Ajouter des "Drop Table"';

$txt['dump_complete_insert'] = 'Insertions compl&egrave;tes';

$txt['dump_split'] = 'Nb de requte / fichier';

$txt['dump_split_expl'] = '(Si 0, un seul fichier sera g&eacute;n&eacute;r&eacute;)';

$txt['dump_csv'] = 'Donnes CSV';

$txt['dump_csv_separator'] = 'S&eacute;parateur CSV';

$txt['dump_csv_eol'] = 'Fin de ligne CSV';

$txt['dump_query'] = 'Requ&ecirc;te SQL pour le dump';

$txt['dump_transmit'] = 'T&eacute;l&eacute;charger';

$txt['dump_in_progress'] = 'Export multiple en cours';

$txt['dump_finished'] = 'Export termin&eacute;';

$txt['dump_status'] = 'Export des requ&ecirc;tes';

$txt['dump_must_choose_tbl'] = 'Vous devez choisir au moins une table';

$txt['dump_mult'] = 'Exporter les tables';

$txt['dump_wait'] = 'Export en cours, veuillez patienter jusqu\' ce que votre navigateur vous propose de sauvegarder le fichier';

$txt['dump_dont_start'] = 'Si le tlchargement ne commence pas, cliquez';

$txt['dump_here'] = 'ici';

$txt['dump_file'] = 'Fichier';

$txt['dump_replace'] = 'Remplacer les donnes de la table';

$txt['dump_fields_terminated'] = 'Champs termins par';

$txt['dump_fields_surrounded'] = 'Champs entours par';

$txt['dump_special_char'] = 'Caractre spcial';

$txt['dump_lines_terminated'] = 'Lignes termines par';

$txt['dump_columns_names'] = 'Noms des colonnes';

$txt['dump_protect'] = 'Prot&eacute;ger les champs et les noms de tables par des ``';

$txt['dump_xml'] = 'Export XML';

$txt['dump_zip'] = 'Compression zip';

$txt['dump_gzip'] = 'Compression gzip';

$txt['dump_bzip'] = 'Compression bzip';



$txt['setup_title'] = 'Configuration de eSKUeL';

$txt['setup_name'] = 'Nom de cette configuration';

$txt['setup_add_entry'] = 'Ajouter une nouvelle entre de configuration';

$txt['setup_mod_entry'] = 'Modifier une configuration';

$txt['setup_mod_globals'] = 'Modifier les variables globales';

$txt['setup_del_entry'] = 'Supprimer une configuration';

$txt['setup_del_tpl'] = 'Supprimer un habillage';

$txt['setup_return_eskuel'] = 'Retour  eSKUeL';

$txt['setup_only_db'] = 'Seulement la base';

$txt['setup_tpl'] = 'Habillage';

$txt['setup_sure'] = 'Etes vous sur(e) de vouloir supprimer';

$txt['setup_mod_cfg_nb'] = 'Modification de la configuration N';

$txt['setup_back_hp'] = 'Retour  la home page';

$txt['setup_tpl_create'] = 'Crer un nouvel habillage';

$txt['setup_tpl_mod'] = 'Modifier un habillage';

$txt['setup_defaultPerRequest'] = 'Nombre de rsultats par dfaut';

$txt['setup_defaultConf'] = 'Configuration par dfaut';

$txt['setup_defaultTxt'] = 'Langue par dfaut';

$txt['setup_tipsOfTheDay'] = 'Afficher l\'astuce du jour';

$txt['setup_manualPopup'] = 'Popup';

$txt['setup_manualDHTML'] = 'DHTML';

$txt['setup_siteUrl'] = 'Url du site';

$txt['setup_tpl_type'] = 'Type d\'habillage';

$txt['setup_3_columns'] = '3 colonnes';

$txt['setup_2_columns'] = '2 colonnes';

$txt['setup_install'] = 'Installation de eSKUeL';

$txt['setup_language'] = 'Choisissez votre langue';

$txt['setup_connection_cfg'] = 'Configuration de connexion';

$txt['setup_global_vars'] = 'Configuration des variables globales';

$txt['setup_step'] = 'Etape';

$txt['setup_back_2_lang'] = 'Retour au choix de la langue';

$txt['setup_error_install'] = 'Vous n\'avez pas rempli correctement les champs obligatoires.';

$txt['setup_congratulation'] = 'Flicitations !<BR><BR>Vous avez correctement install eSKUeL';

$txt['setup_config_saved'] = 'Configuration sauvegarde.';

$txt['setup_hostname'] = 'Nom du serveur MySQL';

$txt['setup_login'] = 'Votre login (identifiant)';

$txt['setup_onlydb'] = 'Nom de votre base de donnes si vous n\'en avez qu\'une seule';

$txt['setup_defaultPerRequest_expl'] = 'Nombre de rsultats pour une requte par page';

$txt['setup_siteUrl_expl'] = 'URL de votre site (utilis pour le logo)';

$txt['setup_mysql_state'] = 'Afficher l\'tat du MySQL';

$txt['setup_mysql_vars'] = 'Afficher les variables du MySQL';

$txt['setup_mysql_process'] = 'Afficher les processus du MySQL';

$txt['setup_nb_char_blob'] = 'Nombre de caractres affichs pour les types TEXT et BLOB';

$txt['setup_nb_chars_add_on'] = 'Pour afficher tout le texte, tapez 0';

$txt['setup_cant_save'] = 'Une incompatibilit technique empche de sauvegarder automatiquement votre configuration.<BR>Pour enregistrer votre configuration, cliquez ci-dessous sur "Slectionner tout", et uploadez le contenu dans le fichier (&agrave; cr&eacute;er ou &agrave; &eacute;craser) ';

$txt['setup_cant_save_2'] = 'sous le rpertoire o vous avez install eSKUeL sur votre FTP.';

$txt['setup_give_name_skin'] = 'Veuillez donner un nom  votre habillage';

$txt['setup_another_name'] = 'Rpertoire dj existant, veuillez choisir un autre nom pour l\'habillage';

$txt['setup_cant_delete_cfg'] = 'Vous ne pouvez pas supprimer votre seule configuration';

$txt['setup_not_supported_windows'] = 'Non disponible sous Windows';



$txt['colorpicker'] 		= 'Slecteur de couleur';

$txt['colorselect'] 		= 'Slectionnez une couleur';

$txt['more'] 				= 'Plus de couleurs';

$txt['color_bg'] 			= 'Arrire-plan de la page';

$txt['color_tbl_bg'] 		= 'Arrire-plan des tableaux';

$txt['color_titre_bg'] 		= 'Arrire-plan des titres';

$txt['color_titre_font'] 	= 'Titres';

$txt['color_border'] 		= 'Bordures';

$txt['color_vlink'] 		= 'Liens visits';

$txt['color_link'] 			= 'Liens';

$txt['color_text'] 			= 'Texte';

$txt['color_alink'] 		= 'Liens actifs';

$txt['color_trou_bg'] 		= 'Arrire-plan des "input"';

$txt['color_trou_font'] 	= 'Texte des "input"';

$txt['color_trou_border'] 	= 'Bordure des "input"';

$txt['color_bosse_bg'] 		= 'Arrire-plan des boutons';

$txt['color_bosse_font'] 	= 'Texte des boutons';

$txt['color_bosse_border'] 	= 'Bordure des boutons';

$txt['color_pick_bg'] 		= 'Arrire-plan des "checkbox"';

$txt['color_pick_border'] 	= 'Bordure des "checkbox"';

$txt['color_preview'] 		= 'Pr&eacute;visualisation';

$txt['color_code'] 			= 'Code couleur';

$txt['color_altern_img'] 	= 'Utiliser d\'autres images';

$txt['color_title_bg'] 		= 'Image de fond du titre';



$txt['preview_input'] 		= 'Input';

$txt['preview_button'] 		= 'Bouton';

$txt['preview_pick'] 		= 'Checkbox';

$txt['preview_text'] 		= 'Exemple de texte';

$txt['preview_link'] 		= '<a href="'.time().'" target="_blank">Exemple de lien</a>';

$txt['preview_vlink'] 		= '<a href="#">Exemple de lien visit</a>';

$txt['check_version'] 		= 'V&eacute;rifier les mises  jour...';



$txt['help'] 				= 'Aide';

$txt['help_chars'] 			= 'caractres';

$txt['help_values'] 		= 'valeurs';

$txt['help_members'] 		= 'membres';

$txt['help_data_types'] 	= 'Aide sur les types de donn&eacute;es';

$txt['help_not_found'] 		= 'Aide non trouv&eacute;e';

$txt['help_close'] 			= 'Quitter l\'aide';



$txt['bkmk_this'] = 'Bookmarker cette requte';

$txt['bkmk_manage'] = 'Gestion des bookmarks';

$txt['bkmk_modify'] = 'Modifier la requ&ecirc;te';

$txt['bkmk_delete'] = 'Supprimer la requ&ecirc;te';

$txt['bkmk_add1'] = 'Ajouter la requ&ecirc;te ';

$txt['bkmk_add2'] = ' &agrave; l\'emplacement :';

$txt['bkmk_query'] = 'La requ&ecirc;te ';

$txt['bkmk_been_saved'] = ' a t sauvegarde';

$txt['bkmk_been_modified'] = ' a t modifie';

$txt['bkmk_been_deleted'] = 'a t supprime';

$txt['bkmk_available'] = '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Requ&ecirc;te(s) disponible(s)&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';



$txt['adm_mysql'] 			= 'Gestion des droits MySQL';

$txt['adm_privileges'] 		= 'Privil&egrave;ges';

$txt['adm_all'] 			= 'Tous';

$txt['adm_all_f'] 			= 'Toutes';

$txt['adm_section_title'] 	= 'Gestion des utilisateurs';

$txt['adm_add'] 			= 'Ajouter un utilisateur';

$txt['adm_db_priv'] 		= 'Afficher les priv. sur une BDD';

$txt['adm_db_priv_full'] 	= 'Afficher les privil&egrave;ges sur la base';

$txt['adm_choose_tbl'] 		= 'Choisissez une table';

$txt['adm_no_priv'] 		= 'Pas de privil&egrave;ge';

$txt['adm_all_hosts'] 		= 'Tous les h&ocirc;tes';

$txt['adm_all_users'] 		= 'Tous les utilisateurs';

$txt['adm_no_password'] 	= 'Pas de mot de passe';

$txt['adm_retype_pass'] 	= 'Retapez le mot de passe';

$txt['adm_user_added'] 		= 'L\'utilisateur a bien &eacute;t&eacute; ajout&eacute;';

$txt['adm_no_forget_reload']= 'N\'oubliez pas de recharger MySQL pour que les modifications soient effectives';

$txt['adm_reload_mysql'] 	= 'Recharger MySQL';

$txt['adm_priv_reloaded'] 	= 'Les privil&egrave;ges ont &eacute;t&eacute; recharg&eacute;s';

$txt['adm_the_user'] 		= 'L\'utilisateur';

$txt['adm_been_deleted'] 	= 'a &eacute;t&eacute; supprim&eacute;';

$txt['adm_no_entry']		= 'Pas d\'entre correspondante';

$txt['adm_keep_password']	= 'Garder le mot de passe actuel';

$txt['adm_user_modified']	= 'L\'utilisateur a bien &eacute;t&eacute; modifi&eacute;';

$txt['adm_revoke']			= 'R&eacute;voquer';

$txt['adm_action']			= 'Action';

$txt['adm_grant_option']	= 'Grant Option';

$txt['adm_revoke_grant']	= 'Rvoquer "grant option"';

$txt['adm_revoke_priv']		= 'Rvoquer les privil&egrave;ges';

$txt['adm_other']			= 'Autres droits';

?>